﻿#if DEBUG
    #define AUTOLOAD
#endif

using Jacquot_Timepix_V2.Models;
using Jacquot_Timepix_V2.Views;
using ScottPlot;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Windows;

namespace Jacquot_Timepix_V2
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
#if DEBUG
        [System.Runtime.InteropServices.DllImport("Kernel32")]
        private static extern void AllocConsole();

        [System.Runtime.InteropServices.DllImport("Kernel32")]
        private static extern void FreeConsole();
#endif
        private readonly ObservableCollection<File> _files = new();
        private readonly List<WpfPlot> _histograms = new();

        public MainWindow()
        {
            InitializeComponent();

            _files = new();

            // defined in .xaml
            _histograms = new() {
                HistogramFillRatio.PlotView,
                HistogramLinearity.PlotView,
                HistogramSize.PlotView,
                HistogramTot.PlotView,
                HistogramVariation.PlotView};
#if DEBUG
            AllocConsole();
#endif

#if AUTOLOAD
            List<string> files = new()
            {
                //"alfa_30V_100thl.txt",
                //"alfa_30V_200thl.txt",
                //"alfa_30V_320thl.txt",
                //"alfa_30V_350thl.txt",
                //"alfa_45V_350thl.txt",
                //"alfa_60V_350thl.txt",
                //"alfa_90V_350thl.txt",

                "He_clus_0deg.txt",
                "He_clus_45deg.txt",
                "He_clus_60deg.txt",

                //"Pions_clus_45deg.txt",
            };
            List<string> folders = new()
            {
                // jacquot work pc
                @"C:\Users\z004dyxm\source\repos\C_TIMEPIX\timepix",

                // jacquot home pc
                @"C:\Users\guill\Desktop\C_TIMEPIX",

                // urban work pc
                @"C:\Users\Urban\Documents\Predmety\Bakalarky\Analýza_Jacquote"
            };

            List<string> filepaths = new();
            foreach (string folder in folders)
            {
                foreach (string file in files)
                {
                    filepaths.Add(folder + "\\" + file);
                }
            }
            foreach (string filepath in filepaths)
            {
                if (System.IO.File.Exists(filepath))
                {
                    File file = new(filepath);
                    if (!_files.Contains(file))
                    {
                        _files.Add(file);
                        file.InitializeHistograms(_histograms);
                    }
                }
            }
#else
            foreach(WpfPlot plot in _histograms)
            {
                plot.Refresh();
            }
#endif
        }

        private void ButtonViewFile_Click(object sender, RoutedEventArgs e)
        {
            FilesView fw = new(_files, _histograms);
            fw.Show();
        }

        //TODO: bind to list of views instead
#region 
        private bool HistogramsInitialized()
        {
            return HistogramFillRatio != null
                && HistogramLinearity != null
                && HistogramSize != null
                && HistogramTot != null
                && HistogramVariation != null;
        }
        private void HistogramFillRatio_Selected(object sender, RoutedEventArgs e)
        {
            if (HistogramsInitialized())
            {
                HistogramFillRatio.Visibility = Visibility.Visible;
                HistogramLinearity.Visibility = Visibility.Hidden;
                HistogramSize.Visibility = Visibility.Hidden;
                HistogramTot.Visibility = Visibility.Hidden;
                HistogramVariation.Visibility = Visibility.Hidden;
            }
        }
        private void HistogramLinearity_Selected(object sender, RoutedEventArgs e)
        {
            if (HistogramsInitialized())
            {
                HistogramFillRatio.Visibility = Visibility.Hidden;
                HistogramLinearity.Visibility = Visibility.Visible;
                HistogramSize.Visibility = Visibility.Hidden;
                HistogramTot.Visibility = Visibility.Hidden;
                HistogramVariation.Visibility = Visibility.Hidden;
            }
        }
        private void HistogramSize_Selected(object sender, RoutedEventArgs e)
        {
            if (HistogramsInitialized())
            {
                HistogramFillRatio.Visibility = Visibility.Hidden;
                HistogramLinearity.Visibility = Visibility.Hidden;
                HistogramSize.Visibility = Visibility.Visible;
                HistogramTot.Visibility = Visibility.Hidden;
                HistogramVariation.Visibility = Visibility.Hidden;
            }
        }
        private void HistogramTot_Selected(object sender, RoutedEventArgs e)
        {
            if (HistogramsInitialized())
            {
                HistogramFillRatio.Visibility = Visibility.Hidden;
                HistogramLinearity.Visibility = Visibility.Hidden;
                HistogramSize.Visibility = Visibility.Hidden;
                HistogramTot.Visibility = Visibility.Visible;
                HistogramVariation.Visibility = Visibility.Hidden;
            }
        }

        private void HistogramVariation_Selected(object sender, RoutedEventArgs e)
        {
            if (HistogramsInitialized())
            {
                HistogramFillRatio.Visibility = Visibility.Hidden;
                HistogramLinearity.Visibility = Visibility.Hidden;
                HistogramSize.Visibility = Visibility.Hidden;
                HistogramTot.Visibility = Visibility.Hidden;
                HistogramVariation.Visibility = Visibility.Visible;
            }
        }
        #endregion

        private void Window_Closed(object sender, System.EventArgs e)
        {
#if DEBUG
            FreeConsole();
#endif
        }
    }
}
