﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Windows;
using Jacquot_Timepix_V2.Models;
using Microsoft.Win32;
using ScottPlot;

namespace Jacquot_Timepix_V2.Views
{
    /// <summary>
    /// Interaction logic for FilesView.xaml
    /// </summary>
    public partial class FilesView : Window
    {
        private readonly List<WpfPlot> _histograms;

        public ObservableCollection<File> Files { get; }

        public FilesView(ObservableCollection<File> files, List<WpfPlot> histograms)
        {
            DataContext = this;
            Files = files;
            _histograms = histograms;

            InitializeComponent();
        }

        private void ButtonUploadFile_Click(object sender, RoutedEventArgs e)
        {
            OpenFileDialog dialog = new()
            {
                InitialDirectory = Environment.GetFolderPath(Environment.SpecialFolder.Desktop),
                Filter = "Text|*.txt|All|*.*"
            };

            if (dialog.ShowDialog() == true)
            {
                File file = new(dialog.FileName);
                if (!Files.Contains(file))
                {
                    Files.Add(file);
                    file.InitializeHistograms(_histograms);
                }
            }
        }

        private void ButtonShowAll_Click(object sender, RoutedEventArgs e)
        {
            foreach (File file in Files)
            {
                file.Show = true;
            }
        }

        private void ButtonHideAll_Click(object sender, RoutedEventArgs e)
        {
            foreach (File file in Files)
            {
                file.Show = false;
            }
        }
    }
}
